django_analyses.filters.pipeline package — django_analyses 0.0.3 documentation

# django_analyses.filters.pipeline package

## Submodules

## django_analyses.filters.pipeline.node module

class `django_analyses.filters.pipeline.node.` `NodeFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Node` model.

  class `Meta`

    Bases: `object`

    `fields` = ('analysis_version',)
    `model`

      alias of `django_analyses.models.pipeline.node.Node`

  `base_filters` = {'analysis_version': <django_filters.filters.ModelChoiceFilter object>}
  `declared_filters` = {}

## django_analyses.filters.pipeline.pipe module

class `django_analyses.filters.pipeline.pipe.` `PipeFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Pipe` model.

  class `Meta`

    Bases: `object`

    `fields` = ('pipeline', 'source', 'base_source_port', 'destination', 'base_destination_port')
    `model`

      alias of `django_analyses.models.pipeline.pipe.Pipe`

  `base_filters` = {'base_destination_port': <django_filters.filters.ModelChoiceFilter object>, 'base_source_port': <django_filters.filters.ModelChoiceFilter object>, 'destination': <django_filters.filters.ModelChoiceFilter object>, 'pipeline': <django_filters.filters.ModelChoiceFilter object>, 'source': <django_filters.filters.ModelChoiceFilter object>}
  `declared_filters` = {}

## django_analyses.filters.pipeline.pipeline module

class `django_analyses.filters.pipeline.pipeline.` `PipelineFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Pipeline` model.

  class `Meta`

    Bases: `object`

    `fields` = ('title', 'description', 'created', 'modified')
    `model`

      alias of `django_analyses.models.pipeline.pipeline.Pipeline`

  `base_filters` = {'created': <django_filters.filters.IsoDateTimeFilter object>, 'description': <django_filters.filters.CharFilter object>, 'modified': <django_filters.filters.IsoDateTimeFilter object>, 'title': <django_filters.filters.CharFilter object>}
  `declared_filters` = {}

## Module contents